from setuptools import setup

setup(
    name='package_eh',
    packages=['package_eh'],
    description='Hello world enterprise edition',
    version='0.9.0.1',
    url=None,
    author='eh',
    author_email='eh@prism39.com',
    keywords=['pip','eh','example']
    )

